@@ -330,10 +330,10 @@ save_timer_presets (void)
 	xmlDocPtr doc;
 	xmlNodePtr root;
 	
-	doc = xmlNewDoc ("1.0");
-	root = xmlNewDocNode (doc, NULL, "timerapplet", NULL);
+	doc = xmlNewDoc ((xmlChar *) "1.0");
+	root = xmlNewDocNode (doc, NULL, (xmlChar *) "timerapplet", NULL);
 	xmlDocSetRootElement (doc, root);
-	xmlNewProp (root, "version", TIMER_APPLET_DATA_FILE_VERSION);
+	xmlNewProp (root, (xmlChar *) "version", (xmlChar *) TIMER_APPLET_DATA_FILE_VERSION);
 	
 	{
 		GtkTreeIter iter;
@@ -354,13 +354,13 @@ save_timer_presets (void)
 				xmlNodePtr node;
 				gchar *profile_duration_str;
 				
-				node = xmlNewChild (root, NULL, "profile", NULL);
+				node = xmlNewChild (root, NULL, (xmlChar *) "profile", NULL);
 				profile_duration_str = g_strdup_printf ("%f", profile_duration);
 				
 				g_assert (profile_duration_str);
 				
-				xmlNewProp (node, "name", profile_name);
-				xmlNewProp (node, "duration", profile_duration_str);
+				xmlNewProp (node, (xmlChar *) "name", (xmlChar *) profile_name);
+				xmlNewProp (node, (xmlChar *) "duration", (xmlChar *) profile_duration_str);
 				
 				g_free (profile_duration_str);
 				profile_duration_str = NULL;
@@ -414,7 +414,7 @@ load_timer_presets (void)
 	}
 	
 	root = xmlDocGetRootElement (doc);
-	if (!root || xmlStrcmp (root->name, (const xmlChar *) "timerapplet")) {
+	if (!root || xmlStrcmp (root->name, (xmlChar *) "timerapplet")) {
 		/* the file was corrupted */
 		xmlFreeDoc (doc);
 		save_timer_presets ();
@@ -424,27 +424,27 @@ load_timer_presets (void)
 	node = root->xmlChildrenNode;
 	
 	while (node) {
-		if (xmlStrcmp (node->name, (const xmlChar *) "profile") == 0) {
-			gchar *profile_name;
+		if (xmlStrcmp (node->name, (xmlChar *) "profile") == 0) {
+			xmlChar *profile_name;
 			gdouble profile_duration;
 			
-			profile_name = xmlGetProp (node, "name");
+			profile_name = xmlGetProp (node, (xmlChar *) "name");
 			
 			/* Get the duration and convert it to a gdouble */
 			{
-				gchar *profile_duration_str;
-				profile_duration_str = xmlGetProp (node, "duration");
+				xmlChar *profile_duration_str;
+				profile_duration_str = xmlGetProp (node, (xmlChar *) "duration");
 				g_assert (profile_duration_str);
-				profile_duration = atof (profile_duration_str);
-				g_free (profile_duration_str);
+				profile_duration = atof ((const char *)profile_duration_str);
+				xmlFree (profile_duration_str);
 				profile_duration_str = NULL;
 			}
 			
 			g_assert (profile_name);
 			g_assert (profile_duration >= 0);
-			timer_applet_add_preset (profile_name, profile_duration);
+			timer_applet_add_preset ((const gchar *)profile_name, profile_duration);
 			
-			g_free (profile_name);
+			xmlFree (profile_name);
 			profile_name = NULL;
 		}
 		node = node->next;
@@ -763,10 +763,10 @@ ask_user_resume_timer (TimerApplet *timer_applet)
 		remaining_time_str = construct_time_str (timer_applet_get_remaining_time (timer_applet), TRUE);
 		if (timer_applet->cur_profile_name) {
 			/* Resume the "<timer name>" timer? */
-			dialog_header_text = g_strdup_printf(_("Resume the \"%s\" timer?"), timer_applet->cur_profile_name, remaining_time_str);
+			dialog_header_text = g_strdup_printf(_("Resume the \"%s\" timer?"), timer_applet->cur_profile_name);
 		}
 		else {
-			dialog_header_text = g_strdup_printf(_("Resume the timer?"), remaining_time_str);
+			dialog_header_text = g_strdup_printf(_("Resume the timer?"));
 		}
 		/* The timer is currently paused. Would you like to resume countdown from <remaining time>? */
 		dialog_body_text = g_strdup_printf(_("The timer is currently paused. Would you like to resume countdown from %s?"), remaining_time_str);
@@ -899,7 +899,7 @@ timer_applet_start_timer (TimerApplet *timer_applet, const gchar *preset_name, g
  * Used to add a new timer profile with the given name and duration
  */
 GtkTreeRowReference *
-timer_applet_add_preset (gchar *name, gdouble duration)
+timer_applet_add_preset (const gchar *name, gdouble duration)
 {
 	GtkTreeIter iter;
 	gchar *display_name;
